-- name: [CS] Mouser
-- description: Bowser's most loyal henchman \n\n\\#ff7777\\This Pack requires Character Select\nto use as a Library!

--[[
    API Documentation for Character Select can be found below:
    https://github.com/Squishy6094/character-select-coop/wiki/API-Documentation

    Use this if you're curious on how anything here works >v<
	(This is an edited version of the Template File by Squishy)
]]

local TEXT_MOD_NAME = "Mouser"

-- Stops mod from loading if Character Select isn't on
if not _G.charSelectExists then
    djui_popup_create("\\#ffffdc\\\n"..TEXT_MOD_NAME.."\nRequires the Character Select Mod\nto use as a Library!\n\nPlease turn on the Character Select Mod\nand Restart the Room!", 6)
    return 0
end

local E_MODEL_CUSTOM_MODEL = smlua_model_util_get_id("mouser_geo") -- Located in "actors"

local TEX_CUSTOM_LIFE_ICON = get_texture_info("bomb_icon") -- Located in "textures"

-- All Located in "sound" Name them whatever you want. Remember to include the .ogg extension
local VOICETABLE_CHARNAME2 = {
    --[CHAR_SOUND_OKEY_DOKEY] = 'StartLevel.ogg', -- Starting game
	[CHAR_SOUND_LETS_A_GO] = 'Silent.ogg', -- Starting level
	[CHAR_SOUND_PUNCH_YAH] = 'smw_kick.ogg', -- Punch 1
	[CHAR_SOUND_PUNCH_WAH] = 'smw_kick.ogg', -- Punch 2
	[CHAR_SOUND_PUNCH_HOO] = 'smw_yoshi_spit.ogg', -- Punch 3
	[CHAR_SOUND_YAH_WAH_HOO] = {'jump.ogg', 'jump.ogg', 'smb_jump-super.ogg'}, -- First/Second jump sounds
	[CHAR_SOUND_HOOHOO] = 'smb_jump-small.ogg', -- Third jump sound
	[CHAR_SOUND_YAHOO_WAHA_YIPPEE] = {'jump.ogg', 'smw_1-up.ogg'}, -- Triple jump sounds
	[CHAR_SOUND_UH] = 'toss.ogg', -- Wall bonk
	[CHAR_SOUND_UH2] = 'smw_yoshi_runs_away.ogg', -- Landing after long jump
	[CHAR_SOUND_UH2_2] = 'toss.ogg', -- Same sound as UH2; jumping onto ledge
	[CHAR_SOUND_HAHA] = 'smb_powerup.ogg', -- Landing triple jump
	[CHAR_SOUND_YAHOO] = 'toss.ogg', -- Long jump
	[CHAR_SOUND_DOH] = 'smw_1-up.ogg', -- Long jump wall bonk
	[CHAR_SOUND_WHOA] = 'smb_bump.ogg', -- Grabbing ledge
	[CHAR_SOUND_EEUH] = 'toss.ogg', -- Climbing over ledge
	[CHAR_SOUND_WAAAOOOW] = 'smw_lost_a_life.ogg', -- Falling a long distance
	[CHAR_SOUND_TWIRL_BOUNCE] = 'M_boing.ogg', -- Bouncing off of a flower spring
	[CHAR_SOUND_GROUND_POUND_WAH] = 'toss.ogg', 
	[CHAR_SOUND_HRMM] = 'smw_reserve_item_store.ogg', -- Lifting something
	[CHAR_SOUND_HERE_WE_GO] = 'smw_reserve_item_store.ogg', -- Star get
	[CHAR_SOUND_SO_LONGA_BOWSER] = 'toss.ogg', -- Throwing Bowser
--DAMAGE
	[CHAR_SOUND_ATTACKED] = 'smw_reserve_item_store.ogg', -- Damaged
	[CHAR_SOUND_PANTING] = 'smb_bump.ogg', -- Low health
	[CHAR_SOUND_ON_FIRE] = 'smw_yoshi_runs_away.ogg', -- Burned
--SLEEP SOUNDS
	[CHAR_SOUND_IMA_TIRED] = 'Silent.ogg', -- Mario feeling tired
	[CHAR_SOUND_YAWNING] = 'Silent.ogg', -- Mario yawning before he sits down to sleep
	[CHAR_SOUND_SNORING1] = 'Silent.ogg', -- Snore Inhale
	[CHAR_SOUND_SNORING2] = 'Silent.ogg', -- Exhale
	[CHAR_SOUND_SNORING3] = 'Silent.ogg', -- Sleep talking / mumbling
--COUGHING (USED IN THE GAS MAZE)
	[CHAR_SOUND_COUGHING1] = 'Silent.ogg', -- Cough take 1
	[CHAR_SOUND_COUGHING2] = 'Silent.ogg', -- Cough take 2
	[CHAR_SOUND_COUGHING3] = 'Silent.ogg', -- Cough take 3
--DEATH
	[CHAR_SOUND_DYING] = 'smw_lost_a_life.ogg', -- Dying from damage
	[CHAR_SOUND_DROWNING] = 'Silent.ogg', -- Running out of air underwater
	[CHAR_SOUND_MAMA_MIA] = 'smw_stomp_no_damage.ogg' -- Booted out of level
}

-- All Located in "actors"
local CAPTABLE_CHAR = {
    normal = smlua_model_util_get_id("mouser_normal_geo"),
    wing = smlua_model_util_get_id("mouser_wing_geo"),
    metal = smlua_model_util_get_id("mouser_normal_geo"),
}

local PALETTE_CHAR = {
    [PANTS]  = "A7AAD3",
    [SHIRT]  = "FF3267",
    [GLOVES] = "FF3267",
    [SHOES]  = "FF3267",
    [HAIR]   = "A7AAD3",
    [SKIN]   = "FF96C2",
    [CAP]    = "FFFFFF",
	[EMBLEM] = "FF3267"
}

local CSloaded = false
local function on_character_select_load()
    CT_CHARNAME2 = _G.charSelect.character_add("Mouser", {"King Koopa's right-hand Mouse!"}, "Chrrli", {r = 65, g = 67, b = 84}, E_MODEL_CUSTOM_MODEL, CT_CHARNAME2, TEX_CUSTOM_LIFE_ICON)
    _G.charSelect.character_add_caps(E_MODEL_CUSTOM_MODEL, CAPTABLE_CHAR)
    _G.charSelect.character_add_voice(E_MODEL_CUSTOM_MODEL, VOICETABLE_CHARNAME2)
    _G.charSelect.character_add_celebration_star(E_MODEL_CUSTOM_MODEL, E_MODEL_CUSTOM_STAR, TEX_CUSTOM_STAR_ICON)
    _G.charSelect.character_add_palette_preset(E_MODEL_CUSTOM_MODEL, PALETTE_CHAR)
    _G.charSelect.character_add_health_meter(CT_CHARNAME2, HM_CHARNAME2)

    CSloaded = true
end

local function on_character_sound(m, sound)
    if not CSloaded then return end
    if _G.charSelect.character_get_voice(m) == VOICETABLE_CHARNAME2 then return _G.charSelect.voice.sound(m, sound) end
end

local function on_character_snore(m)
    if not CSloaded then return end
    if _G.charSelect.character_get_voice(m) == VOICETABLE_CHARNAME2 then return _G.charSelect.voice.snore(m) end
end

hook_event(HOOK_ON_MODS_LOADED, on_character_select_load)
hook_event(HOOK_CHARACTER_SOUND, on_character_sound)
hook_event(HOOK_MARIO_UPDATE, on_character_snore)